==> integration-test-utils-4.4.0-sources.jar: org/wso2/esb/integration/common/utils/common/XmlFileReaderUtil.java <==
/*
 *Copyright (c) 2005-2010, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *WSO2 Inc. licenses this file to you under the Apache License,
 *Version 2.0 (the "License"); you may not use this file except
 *in compliance with the License.
 *You may obtain a copy of the License at
 *
 *http://www.apache.org/licenses/LICENSE-2.0
 *
 *Unless required by applicable law or agreed to in writing,
 *software distributed under the License is distributed on an
 *"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *KIND, either express or implied.  See the License for the
 *specific language governing permissions and limitations
 *under the License.
 */

package org.wso2.esb.integration.common.utils.common;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.impl.builder.StAXOMBuilder;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;

public class XmlFileReaderUtil {
    public static OMElement read(String filePath) throws FileNotFoundException, XMLStreamException {
        OMElement documentElement = null;
        FileInputStream inputStream = null;
        XMLStreamReader parser = null;
        File file = new File(filePath);
        try {

            inputStream = new FileInputStream(filePath);
            parser = XMLInputFactory.newInstance().createXMLStreamReader(inputStream);
            //create the builder
            StAXOMBuilder builder = new StAXOMBuilder(parser);
            //get the root element
            documentElement = builder.getDocumentElement();
            documentElement.build();

        } finally {
            if (parser != null) {
                parser.close();
            }

            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    //ignore
                }
            }
        }
        return documentElement;
    }
}

==> integration-test-utils-4.9.0-sources.jar: org/wso2/esb/integration/common/utils/common/XmlFileReaderUtil.java <==
/*
*Copyright (c) 2005-2010, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
*
*WSO2 Inc. licenses this file to you under the Apache License,
*Version 2.0 (the "License"); you may not use this file except
*in compliance with the License.
*You may obtain a copy of the License at
*
*http://www.apache.org/licenses/LICENSE-2.0
*
*Unless required by applicable law or agreed to in writing,
*software distributed under the License is distributed on an
*"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
*KIND, either express or implied.  See the License for the
*specific language governing permissions and limitations
*under the License.
*/

package org.wso2.esb.integration.common.utils.common;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.impl.builder.StAXOMBuilder;

import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

public class XmlFileReaderUtil {
    public static OMElement read(String filePath) throws FileNotFoundException,
                                                          XMLStreamException {
        OMElement documentElement = null;
        FileInputStream inputStream = null;
        XMLStreamReader parser = null;
        File file = new File(filePath);
        try {

            inputStream = new FileInputStream(filePath);
            parser = XMLInputFactory.newInstance().createXMLStreamReader(inputStream);
            //create the builder
            StAXOMBuilder builder = new StAXOMBuilder(parser);
            //get the root element
            documentElement = builder.getDocumentElement();
            documentElement.build();

        } finally {
            if (parser != null) {
                parser.close();
            }

            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    //ignore
                }
            }
        }
        return documentElement;
    }
}
